#!/bin/bash
if [ ! $# == 2 ]; then
  echo "Usage: $0 sub_theme_name [zurb | zurb6 | bootstrap | clean]"
  exit
fi

#Check if folder exists
if [ -d ../$1 ]
then
	echo "the $1 folder already exists"
	exit 1
fi

if [ $2 != 'zurb' ] && [ $2 != 'zurb6' ] && [ $2 != 'bootstrap' ] && [ $2 != 'clean' ]
then
	echo "You need to provide the framework you want to use zurb, zurb6, bootstrap or clean"
	exit 1;
fi

type bower >/dev/null 2>&1 || { echo >&2 "I require bower but it's not installed.  Aborting."; exit 1; }

if [ $2 == 'zurb' ]
then
type foundation >/dev/null 2>&1 || { echo >&2 "I require foundation CLI but it's not installed.  Aborting."; exit 1; }
fi

#create folder for subtheme
mkdir ../$1

#Copy basic files and folders
cp *png ../$1
cp *.rb ../$1
cp *.txt ../$1
mkdir ../$1/templates
cp templates/block--whitecanvas-account-menu.html.twig ../$1/templates/block--$1-account-menu.html.twig
cp templates/block--whitecanvas-main-menu.html.twig ../$1/templates/block--$1-main-menu.html.twig

mkdir ../$1/css
mkdir ../$1/config
mkdir ../$1/config/install
mkdir ../$1/config/schema


#copy starterkit files
cp starterkit/starterkit.info.yml.example ../$1/$1.info.yml
cp starterkit/starterkit.theme.example ../$1/$1.theme
cp starterkit/starterkit.libraries.yml ../$1/$1.libraries.yml
cp starterkit/starterkit.schema.yml ../$1/config/schema/$1.schema.yml
cp starterkit/starterkit.breakpoints.yml ../$1/config/install/$1.breakpoints.yml

#specific framework tasks
	mkdir ../$1/scss
	cp -rf ../whitecanvas/scss/base ../$1/scss
	cp -rf ../whitecanvas/scss/components ../$1/scss
	cp -rf ../whitecanvas/scss/layout ../$1/scss
	cp -rf ../whitecanvas/scss/states ../$1/scss
	cp -rf ../whitecanvas/scss/theme ../$1/scss



#foundation
if [ $2 == 'zurb' ]
then
	cp foundation.bower.json ../$1/bower.json
	cp -rf scss/foundation ../$1/scss
	cp scss/whitecanvas-foundation.scss ../$1/scss/$1-foundation.scss
	cp -rf js ../$1
	cp starterkit/starterkit.foundation.settings.yml.example ../$1/$1.settings.yml
	cd ../$1
	foundation update
	cp bower_components/foundation/scss/foundation/_settings.scss scss/foundation
fi
#foundation6
if [ $2 == 'zurb6' ]
then
	git clone https://github.com/zurb/foundation-sites-template temp
        cp temp/bower.json ../$1/bower.json
        cp -rf scss/foundation6 ../$1/scss
        cp scss/whitecanvas-foundation6.scss ../$1/scss/$1-foundation6.scss
        cp -rf js ../$1
        cp starterkit/starterkit.foundation6.settings.yml.example ../$1/$1.settings.yml
        cp temp/scss/_settings.scss ../$1/scss/foundation6
	cd ../$1
	bower install
	rm -rf temp
fi
#bootstrap
if [ $2 == 'bootstrap' ]
then
	cp -rf scss/*bootstrap* ../$1/scss
	mkdir ../$1/js
	cp starterkit/starterkit.bootstrap.settings.yml.example ../$1/$1.settings.yml
	cd ../$1
	bower install bootstrap-sass
	cp bower_components/bootstrap-sass/assets/stylesheets/bootstrap/_variables.scss scss/bootstrap/_bootstrap-variables.scss
fi

#clean
if [ $2 == 'clean' ]
then
	mkdir ../$1/js
	cp starterkit/starterkit.clean.settings.yml.example ../$1/$1.settings.yml
	cd ../$1
fi

#final Touch
find . -type f -exec sed -i "s/starterkit/$1/g" {} +
